#[repr(u32)]pub enum WriteError {
Unknown = 0,
InvalidKey = 1,
InvalidValue = 2,
AlreadyExists = 3,
UnknownOrdinal_(u32),
}Expand description
An enumeration of things that may go wrong when trying to write a value to our store.
Variants